
--[[
=head1 NAME

applets.Test.TestApplet - User Interface Tests

=head1 DESCRIPTION

This applets is used to test and demonstrate the jive.ui.* stuff.

=head1 FUNCTIONS

Applet related methods are described in L<jive.Applet>. 
TestApplet overrides the following methods:

=cut
--]]


-- stuff we use
local io                     = require("io")
local oo                     = require("loop.simple")
local math                   = require("math")
local string                 = require("string")
local table                  = require("jive.utils.table")
local debug                  = require("jive.utils.debug")

local Applet                 = require("jive.Applet")
local System                 = require("jive.System")
local Event                  = require("jive.ui.Event")
local Group                  = require("jive.ui.Group")
local Framework              = require("jive.ui.Framework")

local Event                  = require("jive.ui.Event")
-- local Choice                 = require("jive.ui.Choice")
local Popup                  = require("jive.ui.Popup")
local SimpleMenu             = require("jive.ui.SimpleMenu")
local Keyboard               = require("jive.ui.Keyboard")
local Textarea               = require("jive.ui.Textarea")
local Textinput              = require("jive.ui.Textinput")
local Window                 = require("jive.ui.Window")
local hasKeyboard, Keyboard  = pcall(require, "jive.ui.Keyboard")

local LocalPlayer            = require("jive.slim.LocalPlayer")

local appletManager          = appletManager


module(..., Framework.constants)
oo.class(_M, Applet)


function menu(self, menuItem)

	log:info("menu")

	-- Menu	
	local menu = SimpleMenu("menu",
		{
			{	text = self:string('DEVICE_MODEL'),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:defineTextValue(menuItem, 'DEVICE_MODEL', 'qwerty')
					-- return EVENT_CONSUME
				end
			},
			{	text = self:string('DEVICE_NAME'),
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:defineTextValue(menuItem, 'DEVICE_NAME', 'qwerty')
					-- return EVENT_CONSUME
				end
			},
			{	text = self:string("RESET"),
				style = 'item_choice',
				sound = "WINDOWSHOW",
				callback = function(event, menuItem)
					self:storeSettings()
					self:getSettings()["DEVICE_ID"]		= self:getDefaultSettings()["DEVICE_ID"]
					self:getSettings()["DEVICE_MODEL"]	= self:getDefaultSettings()["DEVICE_MODEL"]
					self:getSettings()["DEVICE_NAME"]	= self:getDefaultSettings()["DEVICE_NAME"]
					self:storeSettings()
					self:popupmsg('RESET_MSG',5000)
			end
			},
		})

	local window = Window("text_list", self:string('MODELUPDATE')) -- is a really long title to test the bounding box")
	window:addWidget(menu)

	self:tieAndShowWindow(window)
	return window
end


function defineTextValue(self, menuItem, settingskey, kyeboardtype)

    local window = Window("text_list", menuItem.text, "settingsTitle")

	local input = Textinput("textinput", self:getSettings()[settingskey] or "",
		function(_, value)
			log:debug("Input:", value)
			self:getSettings()[settingskey] = value:match'^%s*(.*%S)' or ''
			self:storeSettings()
			LocalPlayer:setDeviceType(self:getSettings()["DEVICE_MODEL"],self:getSettings()["DEVICE_NAME"])

			window:playSound("WINDOWSHOW")
			window:hide(Window.transitionPushLeft)
			return true
		end)

	if hasKeyboard then
		if kyeboardtype == nil then
			kyeboardtype = "qwerty"
		end
		-- use 7.4 keyboard for Touch if available
		local keyboard  = Keyboard("keyboard", kyeboardtype, input)
		local backspace = Keyboard.backspace()
		local group     = Group('keyboard_textinput', { textinput = input, backspace = backspace } )

		window:addWidget(group)
		window:addWidget(keyboard)
		window:focusWidget(group)

	else
		-- backward-compatible to 7.3-controller
		window:addWidget(input)
	end

	self:tieAndShowWindow(window)
	return window
end

-- This is a simple on-screen message.
function popupmsg(self, warning, millis)

       log:info(self:string(warning))
 
       -- create a Popup object, using already established 'toast_popup_text' skin style
       local popupmessage = Popup('toast_popup_text')
 
       -- add message to popup
       local popupmessageMessage = Group("group", {
                       text = Textarea('toast_popup_textarea',self:string(warning)),
             })
       popupmessage:addWidget(popupmessageMessage)
 
       -- display the message for millis
       popupmessage:showBriefly(millis, nil, Window.transitionPushPopupUp, Window.transitionPushPopupDown)		

end


--[[

=head1 LICENSE

This source code is public domain. It is intended for you to use as a starting
point to create your own applet.

=cut
--]]

